@@ -16,6 +16,10 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define G_LOG_DOMAIN "dzl-animation"
+
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <gobject/gvaluecollector.h>
 #include <gdk/gdk.h>
@@ -143,10 +147,12 @@ dzl_animation_alpha_ease_out_cubic (gdouble offset)
 static gdouble
 dzl_animation_alpha_ease_in_out_cubic (gdouble offset)
 {
-  if (offset < .5)
-    return dzl_animation_alpha_ease_in_cubic (offset * 2.0) / 2.0;
-  else
-    return .5 + dzl_animation_alpha_ease_out_cubic ((offset - .5) * 2.0) / 2.0;
+  gdouble p = offset * 2.0;
+
+  if (p < 1.0)
+    return 0.5 * p * p * p;
+  p -= 2.0;
+  return 0.5 * (p * p * p + 2.0);
 }
 
 
@@ -662,17 +668,19 @@ dzl_animation_notify (DzlAnimation *self)
 
 /**
  * dzl_animation_stop:
- * @animation: (in): A #DzlAnimation.
+ * @animation: (nullable): A #DzlAnimation.
  *
  * Stops a running animation. The internal reference to the animation is
  * dropped and therefore may cause the object to finalize.
  *
- * Side effects: None.
+ * As a convenience, this function accepts %NULL for @animation but
+ * does nothing if that should occur.
  */
 void
 dzl_animation_stop (DzlAnimation *animation)
 {
-  g_return_if_fail (DZL_IS_ANIMATION (animation));
+  if (animation == NULL)
+    return;
 
   if (animation->tween_handler)
     {
@@ -1201,7 +1209,7 @@ dzl_animation_calculate_duration (GdkMonitor *monitor,
   gint n_frames;
   guint ret;
 
-#define MM_PER_SECOND       (100.0)
+#define MM_PER_SECOND       (150.0)
 #define MIN_FRAMES_PER_ANIM (5)
 #define MAX_FRAMES_PER_ANIM (500)
 
